@@ -3,11 +3,8 @@ declare(strict_types=1);
 
 class FreshRSS_AlreadySubscribed_Exception extends Minz_Exception {
 
-	private string $feedName = '';
-
-	public function __construct(string $url, string $feedName) {
+	public function __construct(string $url, private readonly string $feedName) {
 		parent::__construct('Already subscribed! ' . $url, 2135);
-		$this->feedName = $feedName;
 	}
 
 	public function feedName(): string {
