@@ -1,9 +1,9 @@
 <?php
+declare(strict_types=1);
 
-class FreshRSS_FeedNotAdded_Exception extends Exception {
+class FreshRSS_FeedNotAdded_Exception extends Minz_Exception {
 
-	/** @var string */
-	private $url = '';
+	private string $url = '';
 
 	public function __construct(string $url) {
 		parent::__construct('Feed not added! ' . $url, 2147);
