@@ -3,11 +3,8 @@ declare(strict_types=1);
 
 class FreshRSS_Zip_Exception extends Minz_Exception {
 
-	private int $zipErrorCode = 0;
-
-	public function __construct(int $zipErrorCode) {
+	public function __construct(private readonly int $zipErrorCode) {
 		parent::__construct('ZIP error!', 2141);
-		$this->zipErrorCode = $zipErrorCode;
 	}
 
 	public function zipErrorCode(): int {
