@@ -7,20 +7,16 @@ declare(strict_types=1);
  */
 final class FreshRSS_Context {
 
-	/**
-	 * @var array<int,FreshRSS_Category>
-	 */
+	/** @var array<int,FreshRSS_Category> where the key is the category ID */
 	private static array $categories = [];
-	/**
-	 * @var array<int,FreshRSS_Tag>
-	 */
+	/** @var array<int,FreshRSS_Tag> where the key is the label ID */
 	private static array $tags = [];
 	public static string $name = '';
 	public static string $description = '';
 	public static int $total_unread = 0;
 	public static int $total_important_unread = 0;
 
-	/** @var array{'all':int,'read':int,'unread':int} */
+	/** @var array{all:int,read:int,unread:int} */
 	public static array $total_starred = [
 		'all' => 0,
 		'read' => 0,
@@ -29,29 +25,32 @@ final class FreshRSS_Context {
 
 	public static int $get_unread = 0;
 
-	/** @var array{'all':bool,'starred':bool,'important':bool,'feed':int|false,'category':int|false,'tag':int|false,'tags':bool} */
+	/** @var array{all:bool,A:bool,starred:bool,important:bool,feed:int|false,category:int|false,tag:int|false,tags:bool,Z:bool} */
 	public static array $current_get = [
 		'all' => false,
+		'A' => false,
 		'starred' => false,
 		'important' => false,
 		'feed' => false,
 		'category' => false,
 		'tag' => false,
 		'tags' => false,
+		'Z' => false,
 	];
 
 	public static string $next_get = 'a';
 	public static int $state = 0;
-	/**
-	 * @phpstan-var 'ASC'|'DESC'
-	 */
+	/** @var 'ASC'|'DESC' */
 	public static string $order = 'DESC';
+	/** @var 'id'|'date'|'link'|'title'|'rand' */
+	public static string $sort = 'id';
 	public static int $number = 0;
 	public static int $offset = 0;
 	public static FreshRSS_BooleanSearch $search;
-	public static string $first_id = '';
-	public static string $next_id = '';
-	public static string $id_max = '';
+	/** @var numeric-string */
+	public static string $continuation_id = '0';
+	/** @var numeric-string */
+	public static string $id_max = '0';
 	public static int $sinceHours = 0;
 	public static bool $isCli = false;
 
@@ -174,25 +173,25 @@ final class FreshRSS_Context {
 		FreshRSS_Context::$user_conf = null;
 	}
 
-	/** @return array<int,FreshRSS_Category> */
+	/** @return array<int,FreshRSS_Category> where the key is the category ID */
 	public static function categories(): array {
 		if (empty(self::$categories)) {
 			$catDAO = FreshRSS_Factory::createCategoryDao();
-			self::$categories = $catDAO->listSortedCategories(true, false);
+			self::$categories = $catDAO->listSortedCategories(prePopulateFeeds: true, details: false);
 		}
 		return self::$categories;
 	}
 
-	/** @return array<int,FreshRSS_Feed> */
+	/** @return array<int,FreshRSS_Feed> where the key is the feed ID */
 	public static function feeds(): array {
 		return FreshRSS_Category::findFeeds(self::categories());
 	}
 
-	/** @return array<int,FreshRSS_Tag> */
+	/** @return array<int,FreshRSS_Tag> where the key is the label ID */
 	public static function labels(bool $precounts = false): array {
 		if (empty(self::$tags) || $precounts) {
 			$tagDAO = FreshRSS_Factory::createTagDao();
-			self::$tags = $tagDAO->listTags($precounts) ?: [];
+			self::$tags = $tagDAO->listTags($precounts);
 		}
 		return self::$tags;
 	}
@@ -223,22 +222,24 @@ final class FreshRSS_Context {
 		self::_get(Minz_Request::paramString('get') ?: 'a');
 
 		self::$state = Minz_Request::paramInt('state') ?: FreshRSS_Context::userConf()->default_state;
-		$state_forced_by_user = Minz_Request::paramString('state') !== '';
-		if (!$state_forced_by_user && !self::isStateEnabled(FreshRSS_Entry::STATE_READ)) {
-			if (FreshRSS_Context::userConf()->default_view === 'all') {
-				self::$state |= FreshRSS_Entry::STATE_ALL;
+		$state_forced_by_user = Minz_Request::paramString('state', true) !== '';
+		if (!$state_forced_by_user) {
+			if (FreshRSS_Context::userConf()->show_fav_unread && (self::isCurrentGet('s') || self::isCurrentGet('T') || self::isTag())) {
+				self::$state = FreshRSS_Entry::STATE_NOT_READ | FreshRSS_Entry::STATE_READ;
+			} elseif (FreshRSS_Context::userConf()->default_view === 'all') {
+				self::$state = FreshRSS_Entry::STATE_NOT_READ | FreshRSS_Entry::STATE_READ;
+			} elseif (FreshRSS_Context::userConf()->default_view === 'unread_or_favorite') {
+				self::$state = FreshRSS_Entry::STATE_OR_NOT_READ | FreshRSS_Entry::STATE_OR_FAVORITE;
 			} elseif (FreshRSS_Context::userConf()->default_view === 'adaptive' && self::$get_unread <= 0) {
-				self::$state |= FreshRSS_Entry::STATE_READ;
-			}
-			if (FreshRSS_Context::userConf()->show_fav_unread &&
-					(self::isCurrentGet('s') || self::isCurrentGet('T') || self::isTag())) {
-				self::$state |= FreshRSS_Entry::STATE_READ;
+				self::$state = FreshRSS_Entry::STATE_NOT_READ | FreshRSS_Entry::STATE_READ;
 			}
 		}
 
 		self::$search = new FreshRSS_BooleanSearch(Minz_Request::paramString('search'));
-		$order = Minz_Request::paramString('order') ?: FreshRSS_Context::userConf()->sort_order;
+		$order = Minz_Request::paramString('order', true) ?: FreshRSS_Context::userConf()->sort_order;
 		self::$order = in_array($order, ['ASC', 'DESC'], true) ? $order : 'DESC';
+		$sort = Minz_Request::paramString('sort', true) ?: FreshRSS_Context::userConf()->sort;
+		self::$sort = in_array($sort, ['id', 'date', 'link', 'title', 'rand'], true) ? $sort : 'id';
 		self::$number = Minz_Request::paramInt('nb') ?: FreshRSS_Context::userConf()->posts_per_page;
 		if (self::$number > FreshRSS_Context::userConf()->max_posts_per_rss) {
 			self::$number = max(
@@ -246,7 +247,10 @@ final class FreshRSS_Context {
 				FreshRSS_Context::userConf()->posts_per_page);
 		}
 		self::$offset = Minz_Request::paramInt('offset');
-		self::$first_id = Minz_Request::paramString('next');
+		$id_max = Minz_Request::paramString('idMax', true);
+		self::$id_max = ctype_digit($id_max) ? $id_max : '0';
+		$continuation_id = Minz_Request::paramString('cid', true);
+		self::$continuation_id = ctype_digit($continuation_id) ? $continuation_id : '0';
 		self::$sinceHours = Minz_Request::paramInt('hours');
 	}
 
@@ -271,12 +275,14 @@ final class FreshRSS_Context {
 	 * Return the current get as a string or an array.
 	 *
 	 * If $array is true, the first item of the returned value is 'f' or 'c' or 't' and the second is the id.
-	 * @phpstan-return ($asArray is true ? array{'a'|'c'|'f'|'i'|'s'|'t'|'T',bool|int} : string)
+	 * @phpstan-return ($asArray is true ? array{'a'|'A'|'c'|'f'|'i'|'s'|'t'|'T'|'Z',bool|int} : string)
 	 * @return string|array{string,bool|int}
 	 */
-	public static function currentGet(bool $asArray = false) {
+	public static function currentGet(bool $asArray = false): string|array {
 		if (self::$current_get['all']) {
 			return $asArray ? ['a', true] : 'a';
+		} elseif (self::$current_get['A']) {
+			return $asArray ? ['A', true] : 'A';
 		} elseif (self::$current_get['important']) {
 			return $asArray ? ['i', true] : 'i';
 		} elseif (self::$current_get['starred']) {
@@ -301,6 +307,8 @@ final class FreshRSS_Context {
 			}
 		} elseif (self::$current_get['tags']) {
 			return $asArray ? ['T', true] : 'T';
+		} elseif (self::$current_get['Z']) {
+			return $asArray ? ['Z', true] : 'Z';
 		}
 		return '';
 	}
@@ -312,6 +320,14 @@ final class FreshRSS_Context {
 		return self::$current_get['all'] != false;
 	}
 
+	public static function isAllAndCategories(): bool {
+		return self::$current_get['A'] != false;
+	}
+
+	public static function isAllAndArchived(): bool {
+		return self::$current_get['Z'] != false;
+	}
+
 	/**
 	 * @return bool true if the current request targets important feeds, false otherwise.
 	 */
@@ -347,24 +363,18 @@ final class FreshRSS_Context {
 		$type = substr($get, 0, 1);
 		$id = substr($get, 2);
 
-		switch ($type) {
-			case 'a':
-				return self::$current_get['all'];
-			case 'i':
-				return self::$current_get['important'];
-			case 's':
-				return self::$current_get['starred'];
-			case 'f':
-				return self::$current_get['feed'] == $id;
-			case 'c':
-				return self::$current_get['category'] == $id;
-			case 't':
-				return self::$current_get['tag'] == $id;
-			case 'T':
-				return self::$current_get['tags'] || self::$current_get['tag'];
-			default:
-				return false;
-		}
+		return match ($type) {
+			'a' => self::$current_get['all'],
+			'A' => self::$current_get['A'],
+			'i' => self::$current_get['important'],
+			's' => self::$current_get['starred'],
+			'f' => self::$current_get['feed'] == $id,
+			'c' => self::$current_get['category'] == $id,
+			't' => self::$current_get['tag'] == $id,
+			'T' => self::$current_get['tags'] || self::$current_get['tag'],
+			'Z' => self::$current_get['Z'],
+			default => false,
+		};
 	}
 
 	/**
@@ -390,17 +400,27 @@ final class FreshRSS_Context {
 		if (empty(self::$categories)) {
 			$catDAO = FreshRSS_Factory::createCategoryDao();
 			$details = $type === 'f'; 	// Load additional feed details in the case of feed view
-			self::$categories = $catDAO->listCategories(true, $details);
+			self::$categories = $catDAO->listCategories(prePopulateFeeds: true, details: $details);
 		}
 
 		switch ($type) {
-			case 'a':
+			case 'a':	// All PRIORITY_MAIN_STREAM
 				self::$current_get['all'] = true;
+				self::$description = FreshRSS_Context::systemConf()->meta_description;
+				self::$get_unread = self::$total_unread;
+				break;
+			case 'A':	// All except PRIORITY_ARCHIVED
+				self::$current_get['A'] = true;
+				self::$description = FreshRSS_Context::systemConf()->meta_description;
+				self::$get_unread = self::$total_unread;
+				break;
+			case 'Z':	// All including PRIORITY_ARCHIVED
+				self::$current_get['Z'] = true;
 				self::$name = _t('index.feed.title');
 				self::$description = FreshRSS_Context::systemConf()->meta_description;
 				self::$get_unread = self::$total_unread;
 				break;
-			case 'i':
+			case 'i':	// Priority important feeds
 				self::$current_get['important'] = true;
 				self::$name = _t('index.menu.important');
 				self::$description = FreshRSS_Context::systemConf()->meta_description;
@@ -411,7 +431,6 @@ final class FreshRSS_Context {
 				self::$name = _t('index.feed.title_fav');
 				self::$description = FreshRSS_Context::systemConf()->meta_description;
 				self::$get_unread = self::$total_starred['unread'];
-
 				// Update state if favorite is not yet enabled.
 				self::$state = self::$state | FreshRSS_Entry::STATE_FAVORITE;
 				break;
@@ -419,11 +438,7 @@ final class FreshRSS_Context {
 				// We try to find the corresponding feed. When allowing robots, always retrieve the full feed including description
 				$feed = FreshRSS_Context::systemConf()->allow_robots ? null : FreshRSS_Category::findFeed(self::$categories, $id);
 				if ($feed === null) {
-					$feedDAO = FreshRSS_Factory::createFeedDao();
-					$feed = $feedDAO->searchById($id);
-					if ($feed === null) {
-						throw new FreshRSS_Context_Exception('Invalid feed: ' . $id);
-					}
+					throw new FreshRSS_Context_Exception('Invalid feed: ' . $id);
 				}
 				self::$current_get['feed'] = $id;
 				self::$current_get['category'] = $feed->categoryId();
@@ -434,15 +449,15 @@ final class FreshRSS_Context {
 			case 'c':
 				// We try to find the corresponding category.
 				self::$current_get['category'] = $id;
-				if (!isset(self::$categories[$id])) {
-					$catDAO = FreshRSS_Factory::createCategoryDao();
-					$cat = $catDAO->searchById($id);
-					if ($cat === null) {
-						throw new FreshRSS_Context_Exception('Invalid category: ' . $id);
+				$cat = null;
+				foreach (self::$categories as $category) {
+					if ($category->id() === $id) {
+						$cat = $category;
+						break;
 					}
-					self::$categories[$id] = $cat;
-				} else {
-					$cat = self::$categories[$id];
+				}
+				if ($cat === null) {
+					throw new FreshRSS_Context_Exception('Invalid category: ' . $id);
 				}
 				self::$name = $cat->name();
 				self::$get_unread = $cat->nbNotRead();
@@ -450,15 +465,19 @@ final class FreshRSS_Context {
 			case 't':
 				// We try to find the corresponding tag.
 				self::$current_get['tag'] = $id;
-				if (!isset(self::$tags[$id])) {
+				$tag = null;
+				foreach (self::$tags as $t) {
+					if ($t->id() === $id) {
+						$tag = $t;
+						break;
+					}
+				}
+				if ($tag === null) {
 					$tagDAO = FreshRSS_Factory::createTagDao();
 					$tag = $tagDAO->searchById($id);
 					if ($tag === null) {
 						throw new FreshRSS_Context_Exception('Invalid tag: ' . $id);
 					}
-					self::$tags[$id] = $tag;
-				} else {
-					$tag = self::$tags[$id];
 				}
 				self::$name = $tag->name();
 				self::$get_unread = $tag->nbUnread();
@@ -466,7 +485,7 @@ final class FreshRSS_Context {
 			case 'T':
 				$tagDAO = FreshRSS_Factory::createTagDao();
 				self::$current_get['tags'] = true;
-				self::$name = _t('index.menu.tags');
+				self::$name = _t('index.menu.mylabels');
 				self::$get_unread = $tagDAO->countNotRead();
 				break;
 			default:
@@ -486,7 +505,7 @@ final class FreshRSS_Context {
 
 		if (empty(self::$categories)) {
 			$catDAO = FreshRSS_Factory::createCategoryDao();
-			self::$categories = $catDAO->listCategories(true);
+			self::$categories = $catDAO->listCategories(prePopulateFeeds: true);
 		}
 
 		if (FreshRSS_Context::userConf()->onread_jump_next && strlen($get) > 2) {
@@ -541,6 +560,14 @@ final class FreshRSS_Context {
 					// If there is no more unread category, show main stream
 					self::$next_get = $another_unread_id == '' ? 'a' : 'c_' . $another_unread_id;
 					break;
+				case 't':
+					// We can't know what the next unread tag is because entries can be in multiple tags
+					// so marking all entries in a tag can indirectly mark all entries in multiple tags.
+					// Default is to return to the current tag, so mark it as next_get = 'a' instead when
+					// userconf -> onread_jump_next so the readAction knows to jump to the next unread
+					// tag.
+					self::$next_get = 'a';
+					break;
 			}
 		}
 	}
@@ -553,16 +580,8 @@ final class FreshRSS_Context {
 	 *   - the "unread" state is enable
 	 */
 	public static function isAutoRemoveAvailable(): bool {
-		if (!FreshRSS_Context::userConf()->auto_remove_article) {
-			return false;
-		}
-		if (self::isStateEnabled(FreshRSS_Entry::STATE_READ)) {
-			return false;
-		}
-		if (!self::isStateEnabled(FreshRSS_Entry::STATE_NOT_READ)) {
-			return false;
-		}
-		return true;
+		return FreshRSS_Context::userConf()->auto_remove_article && !self::isStateEnabled(FreshRSS_Entry::STATE_READ) &&
+			(self::isStateEnabled(FreshRSS_Entry::STATE_NOT_READ) || self::isStateEnabled(FreshRSS_Entry::STATE_OR_NOT_READ));
 	}
 
 	/**
