@@ -9,6 +9,10 @@ class FreshRSS_Entry extends Minz_Model {
 	public const STATE_ALL = 3;
 	public const STATE_FAVORITE = 4;
 	public const STATE_NOT_FAVORITE = 8;
+	public const STATE_ANDS = self::STATE_READ | self::STATE_NOT_READ | self::STATE_FAVORITE | self::STATE_NOT_FAVORITE;
+	public const STATE_OR_NOT_READ = 32;
+	public const STATE_OR_FAVORITE = 64;
+	public const STATE_ORS = self::STATE_OR_NOT_READ | self::STATE_OR_FAVORITE;
 
 	/** @var numeric-string */
 	private string $id = '0';
@@ -32,13 +36,11 @@ class FreshRSS_Entry extends Minz_Model {
 	private array $tags = [];
 
 	/**
-	 * @param int|string $pubdate
-	 * @param bool|int|null $is_read
-	 * @param bool|int|null $is_favorite
 	 * @param string|array<string> $tags
+	 * @param int|numeric-string $pubdate
 	 */
 	public function __construct(int $feedId = 0, string $guid = '', string $title = '', string $authors = '', string $content = '',
-			string $link = '', $pubdate = 0, $is_read = false, $is_favorite = false, $tags = '') {
+			string $link = '', int|string $pubdate = 0, bool|int|null $is_read = false, bool|int|null $is_favorite = false, $tags = '') {
 		$this->_title($title);
 		$this->_authors($authors);
 		$this->_content($content);
@@ -51,17 +53,21 @@ class FreshRSS_Entry extends Minz_Model {
 		$this->_guid($guid);
 	}
 
-	/** @param array{'id'?:string,'id_feed'?:int,'guid'?:string,'title'?:string,'author'?:string,'content'?:string,'link'?:string,'date'?:int|string,'lastSeen'?:int,
-	 *		'hash'?:string,'is_read'?:bool|int,'is_favorite'?:bool|int,'tags'?:string|array<string>,'attributes'?:?string,'thumbnail'?:string,'timestamp'?:string} $dao */
+	/** @param array{id?:string,id_feed?:int,guid?:string,title?:string,author?:string,content?:string,link?:string,date?:int|string,lastSeen?:int,
+	 *		hash?:string,is_read?:bool|int,is_favorite?:bool|int,tags?:string|array<string>,attributes?:?string,thumbnail?:string,timestamp?:string} $dao */
 	public static function fromArray(array $dao): FreshRSS_Entry {
-		FreshRSS_DatabaseDAO::pdoInt($dao, ['id_feed', 'date', 'lastSeen', 'is_read', 'is_favorite']);
-
-		if (empty($dao['content'])) {
+		if (empty($dao['content']) || !is_string($dao['content'])) {
 			$dao['content'] = '';
 		}
 
+		if (!is_numeric($dao['date'] ?? null)) {
+			$dao['date'] = 0;
+		}
+
 		$dao['attributes'] = empty($dao['attributes']) ? [] : json_decode($dao['attributes'], true);
-		if (!is_array($dao['attributes'])) {
+		if (is_array($dao['attributes'])) {
+			$dao['attributes'] = array_filter($dao['attributes'], 'is_string', ARRAY_FILTER_USE_KEY);
+		} else {
 			$dao['attributes'] = [];
 		}
 
@@ -82,7 +88,7 @@ class FreshRSS_Entry extends Minz_Model {
 			$dao['is_favorite'] ?? false,
 			$dao['tags'] ?? ''
 		);
-		if (!empty($dao['id'])) {
+		if (!empty($dao['id']) && is_numeric($dao['id'])) {
 			$entry->_id($dao['id']);
 		}
 		if (!empty($dao['timestamp'])) {
@@ -149,7 +155,7 @@ class FreshRSS_Entry extends Minz_Model {
 	 * @phpstan-return ($asString is true ? string : array<string>)
 	 * @return string|array<string>
 	 */
-	public function authors(bool $asString = false) {
+	public function authors(bool $asString = false): string|array {
 		if ($asString) {
 			return $this->authors == null ? '' : ';' . implode('; ', $this->authors);
 		} else {
@@ -164,14 +170,14 @@ class FreshRSS_Entry extends Minz_Model {
 		return preg_match('/(?P<delim>[\'"])' . preg_quote($link, '/') . '(?P=delim)/', $html) == 1;
 	}
 
-	/** @param array{'url'?:string,'length'?:int,'medium'?:string,'type'?:string} $enclosure */
+	/** @param array{url?:string,length?:int,medium?:string,type?:string} $enclosure */
 	private static function enclosureIsImage(array $enclosure): bool {
 		$elink = $enclosure['url'] ?? '';
 		$length = $enclosure['length'] ?? 0;
 		$medium = $enclosure['medium'] ?? '';
 		$mime = $enclosure['type'] ?? '';
 
-		return ($elink != '' && $medium === 'image') || strpos($mime, 'image') === 0 ||
+		return ($elink != '' && $medium === 'image') || str_starts_with($mime, 'image') ||
 			($mime == '' && $length == 0 && preg_match('/[.](avif|gif|jpe?g|png|svg|webp)([?#]|$)/i', $elink));
 	}
 
@@ -179,7 +185,8 @@ class FreshRSS_Entry extends Minz_Model {
 	 * Provides the original content without additional content potentially added by loadCompleteContent().
 	 */
 	public function originalContent(): string {
-		return preg_replace('#<!-- FULLCONTENT start //-->.*<!-- FULLCONTENT end //-->#s', '', $this->content) ?? '';
+		return $this->attributeString('original_content') ??
+			preg_replace('#<!-- FULLCONTENT start //-->.*<!-- FULLCONTENT end //-->#s', '', $this->content) ?? '';
 	}
 
 	/**
@@ -225,33 +232,35 @@ HTML;
 				continue;
 			}
 			$credits = $enclosure['credit'] ?? '';
-			$description = nl2br($enclosure['description'] ?? '', true);
-			$length = $enclosure['length'] ?? 0;
-			$medium = $enclosure['medium'] ?? '';
-			$mime = $enclosure['type'] ?? '';
+			$description = is_string($enclosure['description'] ?? null) ? nl2br($enclosure['description'], true) : '';
+			$length = is_numeric($enclosure['length'] ?? null) ? (int)$enclosure['length'] : 0;
+			$medium = is_string($enclosure['medium'] ?? null) ? $enclosure['medium'] : '';
+			$mime = is_string($enclosure['type'] ?? null) ? $enclosure['type'] : '';
 			$thumbnails = $enclosure['thumbnails'] ?? null;
 			if (!is_array($thumbnails)) {
 				$thumbnails = [];
 			}
-			$etitle = $enclosure['title'] ?? '';
+			$etitle = is_string($enclosure['title'] ?? null) ? $enclosure['title'] : '';
 
 			$content .= "\n";
 			$content .= '<figure class="enclosure">';
 
 			foreach ($thumbnails as $thumbnail) {
-				$content .= '<p><img class="enclosure-thumbnail" src="' . $thumbnail . '" alt="" title="' . $etitle . '" /></p>';
+				if (is_string($thumbnail)) {
+					$content .= '<p><img class="enclosure-thumbnail" src="' . $thumbnail . '" alt="" title="' . $etitle . '" /></p>';
+				}
 			}
 
-			if (self::enclosureIsImage($enclosure)) {
+			if (self::enclosureIsImage(['url' => $elink, 'length' => $length, 'medium' => $medium, 'type' => $mime])) {
 				$content .= '<p class="enclosure-content"><img src="' . $elink . '" alt="" title="' . $etitle . '" /></p>';
-			} elseif ($medium === 'audio' || strpos($mime, 'audio') === 0) {
+			} elseif ($medium === 'audio' || str_starts_with($mime, 'audio')) {
 				$content .= '<p class="enclosure-content"><audio preload="none" src="' . $elink
-					. ($length == null ? '' : '" data-length="' . (int)$length)
+					. ($length == null ? '' : '" data-length="' . $length)
 					. ($mime == '' ? '' : '" data-type="' . htmlspecialchars($mime, ENT_COMPAT, 'UTF-8'))
 					. '" controls="controls" title="' . $etitle . '"></audio> <a download="" href="' . $elink . '">💾</a></p>';
-			} elseif ($medium === 'video' || strpos($mime, 'video') === 0) {
+			} elseif ($medium === 'video' || str_starts_with($mime, 'video')) {
 				$content .= '<p class="enclosure-content"><video preload="none" src="' . $elink
-					. ($length == null ? '' : '" data-length="' . (int)$length)
+					. ($length == null ? '' : '" data-length="' . $length)
 					. ($mime == '' ? '' : '" data-type="' . htmlspecialchars($mime, ENT_COMPAT, 'UTF-8'))
 					. '" controls="controls" title="' . $etitle . '"></video> <a download="" href="' . $elink . '">💾</a></p>';
 			} else {	//e.g. application, text, unknown
@@ -266,7 +275,9 @@ HTML;
 					$credits = [$credits];
 				}
 				foreach ($credits as $credit) {
-					$content .= '<p class="enclosure-credits">© ' . $credit . '</p>';
+					if (is_string($credit)) {
+						$content .= '<p class="enclosure-credits">© ' . $credit . '</p>';
+					}
 				}
 			}
 			if ($description != '') {
@@ -281,13 +292,13 @@ HTML;
 	/** @return Traversable<array{'url':string,'type'?:string,'medium'?:string,'length'?:int,'title'?:string,'description'?:string,'credit'?:string|array<string>,'height'?:int,'width'?:int,'thumbnails'?:array<string>}> */
 	public function enclosures(bool $searchBodyImages = false): Traversable {
 		$attributeEnclosures = $this->attributeArray('enclosures');
-		if (is_iterable($attributeEnclosures)) {
+		if (is_array($attributeEnclosures)) {
 			// FreshRSS 1.20.1+: The enclosures are saved as attributes
-			/** @var iterable<array{'url':string,'type'?:string,'medium'?:string,'length'?:int,'title'?:string,'description'?:string,'credit'?:string|array<string>,'height'?:int,'width'?:int,'thumbnails'?:array<string>}> $attributeEnclosures */
+			/** @var list<array{'url':string,'type'?:string,'medium'?:string,'length'?:int,'title'?:string,'description'?:string,'credit'?:string|array<string>,'height'?:int,'width'?:int,'thumbnails'?:array<string>}> $attributeEnclosures */
 			yield from $attributeEnclosures;
 		}
 		try {
-			$searchEnclosures = !is_iterable($attributeEnclosures) && (strpos($this->content, '<p class="enclosure-content') !== false);
+			$searchEnclosures = !is_iterable($attributeEnclosures) && (str_contains($this->content, '<p class="enclosure-content'));
 			$searchBodyImages &= (stripos($this->content, '<img') !== false);
 			$xpath = null;
 			if ($searchEnclosures || $searchBodyImages) {
@@ -352,7 +363,7 @@ HTML;
 	public function thumbnail(bool $searchEnclosures = true): ?array {
 		$thumbnail = $this->attributeArray('thumbnail') ?? [];
 		// First, use the provided thumbnail, if any
-		if (!empty($thumbnail['url'])) {
+		if (is_string($thumbnail['url'] ?? null)) {
 			/** @var array{'url':string,'height'?:int,'width'?:int,'time'?:string} $thumbnail */
 			return $thumbnail;
 		}
@@ -378,15 +389,25 @@ HTML;
 		return null;
 	}
 
-	/** @return string HTML-encoded link of the entry */
-	public function link(): string {
+	/**
+	 * @param bool $raw Set to true to return the raw link,
+	 *  false (default) to attempt a fallback to the GUID if the link is empty.
+	 * @return string HTML-encoded link of the entry
+	 */
+	public function link(bool $raw = false): string {
+		if ($this->link === '' && !$raw) {
+			// Use the GUID as a fallback if it looks like a URL
+			if (filter_var($this->guid, FILTER_VALIDATE_URL, FILTER_NULL_ON_FAILURE) !== null) {
+				return $this->guid;
+			}
+		}
 		return $this->link;
 	}
+
 	/**
 	 * @phpstan-return ($raw is false ? string : int)
-	 * @return string|int
 	 */
-	public function date(bool $raw = false) {
+	public function date(bool $raw = false): int|string {
 		if ($raw) {
 			return $this->date;
 		}
@@ -402,9 +423,8 @@ HTML;
 
 	/**
 	 * @phpstan-return ($raw is false ? string : ($microsecond is true ? string : int))
-	 * @return int|string
 	 */
-	public function dateAdded(bool $raw = false, bool $microsecond = false) {
+	public function dateAdded(bool $raw = false, bool $microsecond = false): int|string {
 		if ($raw) {
 			if ($microsecond) {
 				return $this->date_added;
@@ -451,7 +471,7 @@ HTML;
 	 * @phpstan-return ($asString is true ? string : array<string>)
 	 * @return string|array<string>
 	 */
-	public function tags(bool $asString = false) {
+	public function tags(bool $asString = false): array|string {
 		if ($asString) {
 			return $this->tags == null ? '' : '#' . implode(' #', $this->tags);
 		} else {
@@ -460,7 +480,7 @@ HTML;
 	}
 
 	public function hash(): string {
-		if ($this->hash == '') {
+		if ($this->hash === '') {
 			//Do not include $this->date because it may be automatically generated when lacking
 			$this->hash = md5($this->link . $this->title . $this->authors(true) . $this->originalContent() . $this->tags(true));
 		}
@@ -476,7 +496,7 @@ HTML;
 	}
 
 	/** @param int|numeric-string $value String is for compatibility with 32-bit platforms */
-	public function _id($value): void {
+	public function _id(int|string $value): void {
 		if (is_int($value)) {
 			$value = (string)$value;
 		}
@@ -485,16 +505,11 @@ HTML;
 			$this->date_added = $value;
 		}
 	}
+
 	public function _guid(string $value): void {
-		$value = trim($value);
-		if (empty($value)) {
-			$value = $this->link;
-			if (empty($value)) {
-				$value = $this->hash();
-			}
-		}
-		$this->guid = $value;
+		$this->guid = trim($value);
 	}
+
 	public function _title(string $value): void {
 		$this->hash = '';
 		$this->title = trim($value);
@@ -504,10 +519,10 @@ HTML;
 		$this->_authors($value);
 	}
 	/** @param array<string>|string $value */
-	public function _authors($value): void {
+	public function _authors(array|string $value): void {
 		$this->hash = '';
 		if (!is_array($value)) {
-			if (strpos($value, ';') !== false) {
+			if (str_contains($value, ';')) {
 				$value = htmlspecialchars_decode($value, ENT_QUOTES);
 				$value = preg_split('/\s*[;]\s*/', $value, -1, PREG_SPLIT_NO_EMPTY) ?: [];
 				$value = Minz_Helper::htmlspecialchars_utf8($value);
@@ -525,30 +540,35 @@ HTML;
 		$this->hash = '';
 		$this->link = trim($value);
 	}
-	/** @param int|string $value */
-	public function _date($value): void {
+	/** @param int|numeric-string $value */
+	public function _date(int|string $value): void {
 		$value = (int)$value;
 		$this->date = $value > 1 ? $value : time();
 	}
 
-	public function _lastSeen(int $value): void {
+	/**
+	 * @param int|numeric-string $value
+	 * 32-bit systems provide a string and will fail in year 2038
+	 */
+	public function _lastSeen(int|string $value): void {
+		$value = (int)$value;
 		$this->lastSeen = $value > 0 ? $value : 0;
 	}
 
-	/** @param int|string $value */
-	public function _dateAdded($value, bool $microsecond = false): void {
+	/** @param int|numeric-string $value */
+	public function _dateAdded(int|string $value, bool $microsecond = false): void {
 		if ($microsecond) {
 			$this->date_added = (string)($value);
 		} else {
 			$this->date_added = $value . '000000';
 		}
 	}
-	/** @param bool|int|null $value */
-	public function _isRead($value): void {
+
+	public function _isRead(bool|int|null $value): void {
 		$this->is_read = $value === null ? null : (bool)$value;
 	}
-	/** @param bool|int|null $value */
-	public function _isFavorite($value): void {
+
+	public function _isFavorite(bool|int|null $value): void {
 		$this->is_favorite = $value === null ? null : (bool)$value;
 	}
 
@@ -557,14 +577,13 @@ HTML;
 		$this->feedId = $this->feed == null ? 0 : $this->feed->id();
 	}
 
-	/** @param int|string $id */
-	private function _feedId($id): void {
+	private function _feedId(int $id): void {
 		$this->feed = null;
-		$this->feedId = (int)$id;
+		$this->feedId = $id;
 	}
 
 	/** @param array<string>|string $value */
-	public function _tags($value): void {
+	public function _tags(array|string $value): void {
 		$this->hash = '';
 		if (!is_array($value)) {
 			$value = preg_split('/\s*[#,]\s*/', $value, -1, PREG_SPLIT_NO_EMPTY) ?: [];
@@ -577,122 +596,204 @@ HTML;
 		foreach ($booleanSearch->searches() as $filter) {
 			if ($filter instanceof FreshRSS_BooleanSearch) {
 				// BooleanSearches are combined by AND (default) or OR or AND NOT (special cases) operators and are recursive
-				switch ($filter->operator()) {
-					case 'OR':
-						$ok |= $this->matches($filter);
-						break;
-					case 'OR NOT':
-						$ok |= !$this->matches($filter);
-						break;
-					case 'AND NOT':
-						$ok &= !$this->matches($filter);
-						break;
-					case 'AND':
-					default:
-						$ok &= $this->matches($filter);
-						break;
-				}
+				match ($filter->operator()) {
+					'AND' => $ok &= $this->matches($filter),
+					'OR' => $ok |= $this->matches($filter),
+					'AND NOT' => $ok &= !$this->matches($filter),
+					'OR NOT' => $ok |= !$this->matches($filter),
+					default => $ok &= $this->matches($filter),
+				};
 			} elseif ($filter instanceof FreshRSS_Search) {
 				// Searches are combined by OR and are not recursive
 				$ok = true;
-				if ($filter->getEntryIds()) {
+				if ($filter->getEntryIds() !== null) {
 					$ok &= in_array($this->id, $filter->getEntryIds(), true);
 				}
-				if ($ok && $filter->getNotEntryIds()) {
+				if ($ok && $filter->getNotEntryIds() !== null) {
 					$ok &= !in_array($this->id, $filter->getNotEntryIds(), true);
 				}
-				if ($ok && $filter->getMinDate()) {
+				if ($ok && $filter->getMinDate() !== null) {
 					$ok &= strnatcmp($this->id, $filter->getMinDate() . '000000') >= 0;
 				}
-				if ($ok && $filter->getNotMinDate()) {
+				if ($ok && $filter->getNotMinDate() !== null) {
 					$ok &= strnatcmp($this->id, $filter->getNotMinDate() . '000000') < 0;
 				}
-				if ($ok && $filter->getMaxDate()) {
+				if ($ok && $filter->getMaxDate() !== null) {
 					$ok &= strnatcmp($this->id, $filter->getMaxDate() . '000000') <= 0;
 				}
-				if ($ok && $filter->getNotMaxDate()) {
+				if ($ok && $filter->getNotMaxDate() !== null) {
 					$ok &= strnatcmp($this->id, $filter->getNotMaxDate() . '000000') > 0;
 				}
-				if ($ok && $filter->getMinPubdate()) {
+				if ($ok && $filter->getMinPubdate() !== null) {
 					$ok &= $this->date >= $filter->getMinPubdate();
 				}
-				if ($ok && $filter->getNotMinPubdate()) {
+				if ($ok && $filter->getNotMinPubdate() !== null) {
 					$ok &= $this->date < $filter->getNotMinPubdate();
 				}
-				if ($ok && $filter->getMaxPubdate()) {
+				if ($ok && $filter->getMaxPubdate() !== null) {
 					$ok &= $this->date <= $filter->getMaxPubdate();
 				}
-				if ($ok && $filter->getNotMaxPubdate()) {
+				if ($ok && $filter->getNotMaxPubdate() !== null) {
 					$ok &= $this->date > $filter->getNotMaxPubdate();
 				}
-				if ($ok && $filter->getFeedIds()) {
+				if ($ok && $filter->getFeedIds() !== null) {
 					$ok &= in_array($this->feedId, $filter->getFeedIds(), true);
 				}
-				if ($ok && $filter->getNotFeedIds()) {
+				if ($ok && $filter->getNotFeedIds() !== null) {
 					$ok &= !in_array($this->feedId, $filter->getNotFeedIds(), true);
 				}
-				if ($ok && $filter->getAuthor()) {
+				if ($ok && $filter->getAuthor() !== null) {
 					foreach ($filter->getAuthor() as $author) {
 						$ok &= stripos(implode(';', $this->authors), $author) !== false;
 					}
 				}
-				if ($ok && $filter->getNotAuthor()) {
+				if ($ok && $filter->getAuthorRegex() !== null) {
+					foreach ($filter->getAuthorRegex() as $author) {
+						$ok &= preg_match($author, implode("\n", $this->authors)) === 1;
+					}
+				}
+				if ($ok && $filter->getNotAuthor() !== null) {
 					foreach ($filter->getNotAuthor() as $author) {
 						$ok &= stripos(implode(';', $this->authors), $author) === false;
 					}
 				}
-				if ($ok && $filter->getIntitle()) {
+				if ($ok && $filter->getNotAuthorRegex() !== null) {
+					foreach ($filter->getNotAuthorRegex() as $author) {
+						$ok &= preg_match($author, implode("\n", $this->authors)) === 0;
+					}
+				}
+				if ($ok && $filter->getIntitle() !== null) {
 					foreach ($filter->getIntitle() as $title) {
 						$ok &= stripos($this->title, $title) !== false;
 					}
 				}
-				if ($ok && $filter->getNotIntitle()) {
+				if ($ok && $filter->getIntitleRegex() !== null) {
+					foreach ($filter->getIntitleRegex() as $title) {
+						$ok &= preg_match($title, $this->title) === 1;
+					}
+				}
+				if ($ok && $filter->getNotIntitle() !== null) {
 					foreach ($filter->getNotIntitle() as $title) {
 						$ok &= stripos($this->title, $title) === false;
 					}
 				}
-				if ($ok && $filter->getTags()) {
+				if ($ok && $filter->getNotIntitleRegex() !== null) {
+					foreach ($filter->getNotIntitleRegex() as $title) {
+						$ok &= preg_match($title, $this->title) === 0;
+					}
+				}
+				if ($ok && $filter->getIntext() !== null) {
+					foreach ($filter->getIntext() as $content) {
+						$ok &= stripos($this->content, $content) !== false;
+					}
+				}
+				if ($ok && $filter->getIntextRegex() !== null) {
+					foreach ($filter->getIntextRegex() as $content) {
+						$ok &= preg_match($content, $this->content) === 1;
+					}
+				}
+				if ($ok && $filter->getNotIntext() !== null) {
+					foreach ($filter->getNotIntext() as $content) {
+						$ok &= stripos($this->content, $content) === false;
+					}
+				}
+				if ($ok && $filter->getNotIntextRegex() !== null) {
+					foreach ($filter->getNotIntextRegex() as $content) {
+						$ok &= preg_match($content, $this->content) === 0;
+					}
+				}
+				if ($ok && $filter->getTags() !== null) {
 					foreach ($filter->getTags() as $tag2) {
 						$found = false;
 						foreach ($this->tags as $tag1) {
+							$tag1 = ltrim($tag1, '#');
 							if (strcasecmp($tag1, $tag2) === 0) {
 								$found = true;
+								break;
 							}
 						}
 						$ok &= $found;
 					}
 				}
-				if ($ok && $filter->getNotTags()) {
+				if ($ok && $filter->getTagsRegex() !== null) {
+					foreach ($filter->getTagsRegex() as $tag2) {
+						$found = false;
+						foreach ($this->tags as $tag1) {
+							$tag1 = ltrim($tag1, '#');
+							if (preg_match($tag2, $tag1) === 1) {
+								$found = true;
+								break;
+							}
+						}
+						$ok &= $found;
+					}
+				}
+				if ($ok && $filter->getNotTags() !== null) {
 					foreach ($filter->getNotTags() as $tag2) {
 						$found = false;
 						foreach ($this->tags as $tag1) {
+							$tag1 = ltrim($tag1, '#');
 							if (strcasecmp($tag1, $tag2) === 0) {
 								$found = true;
+								break;
 							}
 						}
 						$ok &= !$found;
 					}
 				}
-				if ($ok && $filter->getInurl()) {
+				if ($ok && $filter->getNotTagsRegex() !== null) {
+					foreach ($filter->getNotTagsRegex() as $tag2) {
+						$found = false;
+						foreach ($this->tags as $tag1) {
+							$tag1 = ltrim($tag1, '#');
+							if (preg_match($tag2, $tag1) === 1) {
+								$found = true;
+								break;
+							}
+						}
+						$ok &= !$found;
+					}
+				}
+				if ($ok && $filter->getInurl() !== null) {
 					foreach ($filter->getInurl() as $url) {
 						$ok &= stripos($this->link, $url) !== false;
 					}
 				}
-				if ($ok && $filter->getNotInurl()) {
+				if ($ok && $filter->getInurlRegex() !== null) {
+					foreach ($filter->getInurlRegex() as $url) {
+						$ok &= preg_match($url, $this->link) === 1;
+					}
+				}
+				if ($ok && $filter->getNotInurl() !== null) {
 					foreach ($filter->getNotInurl() as $url) {
 						$ok &= stripos($this->link, $url) === false;
 					}
 				}
-				if ($ok && $filter->getSearch()) {
+				if ($ok && $filter->getNotInurlRegex() !== null) {
+					foreach ($filter->getNotInurlRegex() as $url) {
+						$ok &= preg_match($url, $this->link) === 0;
+					}
+				}
+				if ($ok && $filter->getSearch() !== null) {
 					foreach ($filter->getSearch() as $needle) {
 						$ok &= (stripos($this->title, $needle) !== false || stripos($this->content, $needle) !== false);
 					}
 				}
-				if ($ok && $filter->getNotSearch()) {
+				if ($ok && $filter->getNotSearch() !== null) {
 					foreach ($filter->getNotSearch() as $needle) {
 						$ok &= (stripos($this->title, $needle) === false && stripos($this->content, $needle) === false);
 					}
 				}
+				if ($ok && $filter->getSearchRegex() !== null) {
+					foreach ($filter->getSearchRegex() as $needle) {
+						$ok &= (preg_match($needle, $this->title) === 1 || preg_match($needle, $this->content) === 1);
+					}
+				}
+				if ($ok && $filter->getNotSearchRegex() !== null) {
+					foreach ($filter->getNotSearchRegex() as $needle) {
+						$ok &= (preg_match($needle, $this->title) === 0 && preg_match($needle, $this->content) === 0);
+					}
+				}
 				if ($ok) {
 					return true;
 				}
@@ -719,9 +820,7 @@ HTML;
 			}
 		}
 		FreshRSS_Context::userConf()->applyFilterActions($this);
-		if ($feed->category() !== null) {
-			$feed->category()->applyFilterActions($this);
-		}
+		$feed->category()?->applyFilterActions($this);
 		$feed->applyFilterActions($this);
 	}
 
@@ -753,6 +852,25 @@ HTML;
 			return '';
 		}
 
+		$conditions = $feed->attributeArray('path_entries_conditions') ?? [];
+		$conditions = array_filter(array_map(fn($v) => is_string($v) ? trim($v) : '', $conditions));
+		if (count($conditions) > 0) {
+			$found = false;
+			foreach ($conditions as $condition) {
+				if (!is_string($condition) || trim($condition) === '') {
+					continue;
+				}
+				$booleanSearch = new FreshRSS_BooleanSearch($condition);
+				if ($this->matches($booleanSearch)) {
+					$found = true;
+					break;
+				}
+			}
+			if (!$found) {
+				return '';
+			}
+		}
+
 		$cachePath = $feed->cacheFilename($url . '#' . $feed->pathEntries());
 		$html = httpGet($url, $cachePath, 'html', $feed->attributes(), $feed->curlOptions());
 		if (strlen($html) > 0) {
@@ -766,7 +884,7 @@ HTML;
 				foreach ($metas as $meta) {
 					if ($meta instanceof DOMElement && strtolower(trim($meta->getAttribute('http-equiv'))) === 'refresh') {
 						$refresh = preg_replace('/^[0-9.; ]*\s*(url\s*=)?\s*/i', '', trim($meta->getAttribute('content')));
-						$refresh = SimplePie_Misc::absolutize_url($refresh, $url);
+						$refresh = is_string($refresh) ? \SimplePie\Misc::absolutize_url($refresh, $url) : false;
 						if ($refresh != false && $refresh !== $url) {
 							return $this->getContentByParsing($refresh, $maxRedirs - 1);
 						}
@@ -777,47 +895,78 @@ HTML;
 			$base = $xpath->evaluate('normalize-space(//base/@href)');
 			if ($base == false || !is_string($base)) {
 				$base = $url;
-			} elseif (substr($base, 0, 2) === '//') {
+			} elseif (str_starts_with($base, '//')) {
 				//Protocol-relative URLs "//www.example.net"
 				$base = (parse_url($url, PHP_URL_SCHEME) ?? 'https') . ':' . $base;
 			}
 
-			$content = '';
+			$html = '';
 			$cssSelector = htmlspecialchars_decode($feed->pathEntries(), ENT_QUOTES);
 			$cssSelector = trim($cssSelector, ', ');
+			$path_entries_filter = trim($feed->attributeString('path_entries_filter') ?? '', ', ');
 			$nodes = $xpath->query((new Gt\CssXPath\Translator($cssSelector, '//'))->asXPath());
 			if ($nodes != false) {
-				$path_entries_filter = $feed->attributeString('path_entries_filter') ?? '';
-				$path_entries_filter = trim($path_entries_filter, ', ');
+				$filter_xpath = $path_entries_filter === '' ? '' : (new Gt\CssXPath\Translator($path_entries_filter, 'descendant-or-self::'))->asXPath();
 				foreach ($nodes as $node) {
-					if ($path_entries_filter !== '') {
-						$filterednodes = $xpath->query((new Gt\CssXPath\Translator($path_entries_filter))->asXPath(), $node) ?: [];
+					if ($filter_xpath !== '' && ($filterednodes = $xpath->query($filter_xpath, $node)) !== false) {
+						// Remove unwanted elements once before sanitizing, for CSS selectors to also match original content
 						foreach ($filterednodes as $filterednode) {
-							if ($filterednode->parentNode === null) {
+							if ($filterednode === $node) {
+								continue 2;
+							}
+							if (!($filterednode instanceof DOMElement) || $filterednode->parentNode === null) {
 								continue;
 							}
 							$filterednode->parentNode->removeChild($filterednode);
 						}
 					}
-					$content .= $doc->saveHTML($node) . "\n";
+					$html .= $doc->saveHTML($node) . "\n";
 				}
 			}
-			$html = trim(sanitizeHTML($content, $base));
-			return $html;
+
+			unset($xpath, $doc);
+			$html = sanitizeHTML($html, $base);
+
+			if ($path_entries_filter !== '') {
+				// Remove unwanted elements again after sanitizing, for CSS selectors to also match sanitized content
+				$modified = false;
+				$doc = new DOMDocument();
+				$utf8BOM = "\xEF\xBB\xBF";
+				$doc->loadHTML($utf8BOM . $html, LIBXML_NONET | LIBXML_NOERROR | LIBXML_NOWARNING);
+				$xpath = new DOMXPath($doc);
+				$filterednodes = $xpath->query((new Gt\CssXPath\Translator($path_entries_filter, '//'))->asXPath()) ?: [];
+				foreach ($filterednodes as $filterednode) {
+					if (!($filterednode instanceof DOMElement) || $filterednode->parentNode === null) {
+						continue;
+					}
+					$filterednode->parentNode->removeChild($filterednode);
+					$modified = true;
+				}
+				if ($modified) {
+					$html = $doc->saveHTML($doc->getElementsByTagName('body')->item(0) ?? $doc->firstElementChild) ?: $html;
+				}
+			}
+
+			return trim($html);
 		} else {
 			throw new Minz_Exception();
 		}
 	}
 
+	/**
+	 * @return bool True if the content was modified, false otherwise
+	 */
 	public function loadCompleteContent(bool $force = false): bool {
 		// Gestion du contenu
 		// Trying to fetch full article content even when feeds do not propose it
 		$feed = $this->feed();
-		if ($feed != null && trim($feed->pathEntries()) != '') {
+		if ($feed === null) {
+			return false;
+		}
+		if (trim($feed->pathEntries()) != '') {
 			$entryDAO = FreshRSS_Factory::createEntryDao();
 			$entry = $force ? null : $entryDAO->searchByGuid($this->feedId, $this->guid);
-
-			if ($entry) {
+			if ($entry !== null) {
 				// l’article existe déjà en BDD, en se contente de recharger ce contenu
 				$this->content = $entry->content(false);
 			} else {
@@ -829,17 +978,19 @@ HTML;
 						$originalContent = $this->originalContent();
 						switch ($feed->attributeString('content_action')) {
 							case 'prepend':
+								$this->_attribute('original_content');
 								$this->content = $fullContent . $originalContent;
 								break;
 							case 'append':
+								$this->_attribute('original_content');
 								$this->content = $originalContent . $fullContent;
 								break;
 							case 'replace':
 							default:
+								$this->_attribute('original_content', $originalContent);
 								$this->content = $fullContent;
 								break;
 						}
-
 						return true;
 					}
 				} catch (Exception $e) {
@@ -847,6 +998,38 @@ HTML;
 					Minz_Log::warning($e->getMessage());
 				}
 			}
+		} elseif (trim($feed->attributeString('path_entries_filter') ?? '') !== '') {
+			$originalContent = $this->attributeString('original_content') ?? $this->content;
+			$doc = new DOMDocument();
+			$utf8BOM = "\xEF\xBB\xBF";
+			if (!$doc->loadHTML($utf8BOM . $originalContent, LIBXML_NONET | LIBXML_NOERROR | LIBXML_NOWARNING)) {
+				return false;
+			}
+			$xpath = new DOMXPath($doc);
+			$filterednodes = $xpath->query((new Gt\CssXPath\Translator($feed->attributeString('path_entries_filter') ?? '', '//'))->asXPath()) ?: [];
+			foreach ($filterednodes as $filterednode) {
+				if (!($filterednode instanceof DOMElement) || $filterednode->parentNode === null) {
+					continue;
+				}
+				$filterednode->parentNode->removeChild($filterednode);
+			}
+			$html = $doc->saveHTML($doc->getElementsByTagName('body')->item(0) ?? $doc->firstElementChild);
+			if (!is_string($html)) {
+				return false;
+			}
+			$html = preg_replace('%^\s*<body>\s*|\s*</body>\s*$%i', '', $html);
+			$this->_attribute('original_content');
+			if (is_string($html) && $this->content !== $html) {
+				$this->_attribute('original_content', $originalContent);
+				$this->content = $html;
+				return true;
+			}
+		} else {
+			$originalContent = $this->originalContent();
+			if ($originalContent !== $this->content) {
+				$this->content = $originalContent;
+				return true;
+			}
 		}
 		return false;
 	}
@@ -862,7 +1045,7 @@ HTML;
 			'title' => $this->title(),
 			'author' => $this->authors(true),
 			'content' => $this->content(false),
-			'link' => $this->link(),
+			'link' => $this->link(raw: true),
 			'date' => $this->date(true),
 			'lastSeen' => $this->lastSeen(),
 			'hash' => $this->hash(),
@@ -901,7 +1084,7 @@ HTML;
 	 * @param numeric-string|int $dec Decimal number
 	 * @return string 64-bit hexa http://code.google.com/p/google-reader-api/wiki/ItemId
 	 */
-	private static function dec2hex($dec): string {
+	private static function dec2hex(string|int $dec): string {
 		return PHP_INT_SIZE < 8 ? // 32-bit ?
 			str_pad(gmp_strval(gmp_init($dec, 10), 16), 16, '0', STR_PAD_LEFT) :
 			str_pad(dechex((int)($dec)), 16, '0', STR_PAD_LEFT);
@@ -965,7 +1148,7 @@ HTML;
 		if ($category != null && $mode !== 'freshrss') {
 			$item['categories'][] = 'user/-/label/' . htmlspecialchars_decode($category->name(), ENT_QUOTES);
 		}
-		if ($feed != null) {
+		if ($feed !== null) {
 			$item['origin']['htmlUrl'] = htmlspecialchars_decode($feed->website());
 			$item['origin']['title'] = $feed->name();	//EasyRSS
 			if ($mode === 'compat') {
