@@ -3,13 +3,11 @@ declare(strict_types=1);
 
 class FreshRSS_FilterAction {
 
-	private FreshRSS_BooleanSearch $booleanSearch;
-	/** @var array<string>|null */
+	/** @var list<string>|null */
 	private ?array $actions = null;
 
 	/** @param array<string> $actions */
-	private function __construct(FreshRSS_BooleanSearch $booleanSearch, array $actions) {
-		$this->booleanSearch = $booleanSearch;
+	private function __construct(private readonly FreshRSS_BooleanSearch $booleanSearch, array $actions) {
 		$this->_actions($actions);
 	}
 
@@ -17,7 +15,7 @@ class FreshRSS_FilterAction {
 		return $this->booleanSearch;
 	}
 
-	/** @return array<string> */
+	/** @return list<string> */
 	public function actions(): array {
 		return $this->actions ?? [];
 	}
@@ -25,7 +23,7 @@ class FreshRSS_FilterAction {
 	/** @param array<string> $actions */
 	public function _actions(?array $actions): void {
 		if (is_array($actions)) {
-			$this->actions = array_unique($actions);
+			$this->actions = array_values(array_unique($actions));
 		} else {
 			$this->actions = null;
 		}
@@ -44,7 +42,8 @@ class FreshRSS_FilterAction {
 
 	/** @param array|mixed|null $json */
 	public static function fromJSON($json): ?FreshRSS_FilterAction {
-		if (is_array($json) && !empty($json['search']) && !empty($json['actions']) && is_array($json['actions'])) {
+		if (is_array($json) && !empty($json['search']) && is_string($json['search']) &&
+			!empty($json['actions']) && is_array($json['actions']) && is_array_values_string($json['actions'])) {
 			return new FreshRSS_FilterAction(new FreshRSS_BooleanSearch($json['search']), $json['actions']);
 		}
 		return null;
