@@ -9,11 +9,11 @@ final class FreshRSS_LogDAO {
 		return USERS_PATH . '/' . (Minz_User::name() ?? Minz_User::INTERNAL_USER) . '/' . $logFileName;
 	}
 
-	/** @return array<FreshRSS_Log> */
+	/** @return list<FreshRSS_Log> */
 	public static function lines(?string $logFileName = null): array {
 		$logs = [];
 		$handle = @fopen(self::logPath($logFileName), 'r');
-		if ($handle) {
+		if (is_resource($handle)) {
 			while (($line = fgets($handle)) !== false) {
 				if (preg_match('/^\[([^\[]+)\] \[([^\[]+)\] --- (.*)$/', $line, $matches)) {
 					$myLog = new FreshRSS_Log();
