@@ -17,11 +17,8 @@ class FreshRSS_Tag extends Minz_Model {
 		return $this->id;
 	}
 
-	/**
-	 * @param int|string $value
-	 */
-	public function _id($value): void {
-		$this->id = (int)$value;
+	public function _id(int $value): void {
+		$this->id = $value;
 	}
 
 	public function name(): string {
@@ -40,11 +37,8 @@ class FreshRSS_Tag extends Minz_Model {
 		return $this->nbEntries;
 	}
 
-	/**
-	 * @param string|int $value
-	 */
-	public function _nbEntries($value): void {
-		$this->nbEntries = (int)$value;
+	public function _nbEntries(int $value): void {
+		$this->nbEntries = $value;
 	}
 
 	public function nbUnread(): int {
@@ -55,10 +49,8 @@ class FreshRSS_Tag extends Minz_Model {
 		return $this->nbUnread;
 	}
 
-	/**
-	 * @param string|int $value
-	 */
-	public function _nbUnread($value): void {
+	/** @param int|numeric-string $value */
+	public function _nbUnread(int|string $value): void {
 		$this->nbUnread = (int)$value;
 	}
 }
