@@ -1,9 +1,10 @@
 <?php
+declare(strict_types=1);
 
 class FreshRSS_TagDAOPGSQL extends FreshRSS_TagDAO {
 
+	#[\Override]
 	public function sqlIgnore(): string {
 		return '';	//TODO
 	}
-
 }
