@@ -3,10 +3,10 @@ declare(strict_types=1);
 
 final class FreshRSS_ViewStats extends FreshRSS_View {
 
-	/** @var array<int,FreshRSS_Category> */
+	/** @var array<int,FreshRSS_Category> where the key is the category ID */
 	public array $categories;
-	public FreshRSS_Feed $feed;
-	/** @var array<int,FreshRSS_Feed> */
+	public ?FreshRSS_Feed $feed = null;
+	/** @var array<int,FreshRSS_Feed> where the key is the feed ID */
 	public array $feeds;
 	public bool $displaySlider = false;
 
@@ -14,7 +14,7 @@ final class FreshRSS_ViewStats extends FreshRSS_View {
 	public float $averageDayOfWeek;
 	public float $averageHour;
 	public float $averageMonth;
-	/** @var array<string> */
+	/** @var list<string> */
 	public array $days;
 	/** @var array<string,array<int,int|string>> */
 	public array $entryByCategory;
@@ -30,11 +30,11 @@ final class FreshRSS_ViewStats extends FreshRSS_View {
 	public array $last30DaysLabel;
 	/** @var array<int,string> */
 	public array $last30DaysLabels;
-	/** @var array<string,string> */
+	/** @var list<string> */
 	public array $months;
-	/** @var array{'total':int,'count_unreads':int,'count_reads':int,'count_favorites':int}|false */
+	/** @var array{total:int,count_unreads:int,count_reads:int,count_favorites:int}|false */
 	public $repartition;
-	/** @var array{'main_stream':array{'total':int,'count_unreads':int,'count_reads':int,'count_favorites':int}|false,'all_feeds':array{'total':int,'count_unreads':int,'count_reads':int,'count_favorites':int}|false} */
+	/** @var array{main_stream:array{total:int,count_unreads:int,count_reads:int,count_favorites:int}|false,all_feeds:array{total:int,count_unreads:int,count_reads:int,count_favorites:int}|false} */
 	public array $repartitions;
 	/** @var array<int,int> */
 	public array $repartitionDayOfWeek;
@@ -42,6 +42,6 @@ final class FreshRSS_ViewStats extends FreshRSS_View {
 	public array $repartitionHour;
 	/** @var array<int,int> */
 	public array $repartitionMonth;
-	/** @var array<array{'id':int,'name':string,'category':string,'count':int}> */
+	/** @var list<array{id:int,name:string,category:string,count:int}> */
 	public array $topFeed;
 }
