@@ -6,7 +6,7 @@ SQL;
 $GLOBALS['SQL_CREATE_TABLES'] = <<<'SQL'
 CREATE TABLE IF NOT EXISTS `_category` (
 	"id" SERIAL PRIMARY KEY,
-	"name" VARCHAR(255) UNIQUE NOT NULL,
+	"name" VARCHAR(191) UNIQUE NOT NULL,
 	"kind" SMALLINT DEFAULT 0,	-- 1.20.0
 	"lastUpdate" BIGINT DEFAULT 0,	-- 1.20.0
 	"error" SMALLINT DEFAULT 0,	-- 1.20.0
@@ -18,13 +18,13 @@ CREATE TABLE IF NOT EXISTS `_feed` (
 	"url" VARCHAR(32768) NOT NULL,
 	"kind" SMALLINT DEFAULT 0, -- 1.20.0
 	"category" INT DEFAULT 0,	-- 1.20.0
-	"name" VARCHAR(255) NOT NULL,
+	"name" VARCHAR(191) NOT NULL,
 	"website" VARCHAR(32768),
 	"description" TEXT,
-	"lastUpdate" INT DEFAULT 0,
+	"lastUpdate" BIGINT DEFAULT 0,
 	"priority" SMALLINT NOT NULL DEFAULT 10,
-	"pathEntries" VARCHAR(511) DEFAULT NULL,
-	"httpAuth" VARCHAR(511) DEFAULT NULL,
+	"pathEntries" VARCHAR(4096) DEFAULT NULL,
+	"httpAuth" VARCHAR(1024) DEFAULT NULL,
 	"error" SMALLINT DEFAULT 0,
 	"ttl" INT NOT NULL DEFAULT 0,
 	"attributes" TEXT,	-- v1.11.0
@@ -37,18 +37,18 @@ CREATE INDEX IF NOT EXISTS `_priority_index` ON `_feed` ("priority");
 
 CREATE TABLE IF NOT EXISTS `_entry` (
 	"id" BIGINT NOT NULL PRIMARY KEY,
-	"guid" VARCHAR(760) NOT NULL,
-	"title" VARCHAR(255) NOT NULL,
-	"author" VARCHAR(255),
+	"guid" VARCHAR(767) NOT NULL,
+	"title" VARCHAR(8192) NOT NULL,
+	"author" VARCHAR(1024),
 	"content" TEXT,
-	"link" VARCHAR(1023) NOT NULL,
-	"date" INT,
-	"lastSeen" INT DEFAULT 0,
+	"link" VARCHAR(16383) NOT NULL,
+	"date" BIGINT,
+	"lastSeen" BIGINT DEFAULT 0,
 	"hash" BYTEA,
 	"is_read" SMALLINT NOT NULL DEFAULT 0,
 	"is_favorite" SMALLINT NOT NULL DEFAULT 0,
 	"id_feed" INT,	-- 1.20.0
-	"tags" VARCHAR(1023),
+	"tags" VARCHAR(2048),
 	"attributes" TEXT,	-- v1.20.0
 	FOREIGN KEY ("id_feed") REFERENCES `_feed` ("id") ON DELETE CASCADE ON UPDATE CASCADE,
 	UNIQUE ("id_feed","guid")
@@ -65,18 +65,18 @@ INSERT INTO `_category` (id, name)
 
 CREATE TABLE IF NOT EXISTS `_entrytmp` (	-- v1.7
 	"id" BIGINT NOT NULL PRIMARY KEY,
-	"guid" VARCHAR(760) NOT NULL,
-	"title" VARCHAR(255) NOT NULL,
-	"author" VARCHAR(255),
+	"guid" VARCHAR(767) NOT NULL,
+	"title" VARCHAR(8192) NOT NULL,
+	"author" VARCHAR(1024),
 	"content" TEXT,
-	"link" VARCHAR(1023) NOT NULL,
-	"date" INT,
-	"lastSeen" INT DEFAULT 0,
+	"link" VARCHAR(16383) NOT NULL,
+	"date" BIGINT,
+	"lastSeen" BIGINT DEFAULT 0,
 	"hash" BYTEA,
 	"is_read" SMALLINT NOT NULL DEFAULT 0,
 	"is_favorite" SMALLINT NOT NULL DEFAULT 0,
 	"id_feed" INT,	-- 1.20.0
-	"tags" VARCHAR(1023),
+	"tags" VARCHAR(2048),
 	"attributes" TEXT,	-- v1.20.0
 	FOREIGN KEY ("id_feed") REFERENCES `_feed` ("id") ON DELETE CASCADE ON UPDATE CASCADE,
 	UNIQUE ("id_feed","guid")
@@ -85,7 +85,7 @@ CREATE INDEX IF NOT EXISTS `_entrytmp_date_index` ON `_entrytmp` ("date");
 
 CREATE TABLE IF NOT EXISTS `_tag` (	-- v1.12
 	"id" SERIAL PRIMARY KEY,
-	"name" VARCHAR(63) UNIQUE NOT NULL,
+	"name" VARCHAR(191) UNIQUE NOT NULL,
 	"attributes" TEXT
 );
 CREATE TABLE IF NOT EXISTS `_entrytag` (
@@ -101,3 +101,45 @@ SQL;
 $GLOBALS['SQL_DROP_TABLES'] = <<<'SQL'
 DROP TABLE IF EXISTS `_entrytag`, `_tag`, `_entrytmp`, `_entry`, `_feed`, `_category`;
 SQL;
+
+$GLOBALS['SQL_UPDATE_MINOR'] = <<<'SQL'
+DO $$
+BEGIN
+	IF NOT EXISTS (
+		SELECT 1 FROM information_schema.columns
+		WHERE table_schema = 'public'
+			AND table_name = REPLACE('`_tag`', '"', '')
+			AND column_name = 'name'
+			AND character_maximum_length = 191
+	) THEN
+		ALTER TABLE `_category`
+			ALTER COLUMN "name" SET DATA TYPE VARCHAR(191);
+		ALTER TABLE `_feed`
+			DROP CONSTRAINT IF EXISTS `_feed_url_key`,
+			ALTER COLUMN "url" SET DATA TYPE VARCHAR(32768),
+			ALTER COLUMN "name" SET DATA TYPE VARCHAR(191),
+			ALTER COLUMN "website" SET DATA TYPE VARCHAR(32768),
+			ALTER COLUMN "lastUpdate" SET DATA TYPE BIGINT,
+			ALTER COLUMN "pathEntries" SET DATA TYPE VARCHAR(4096),
+			ALTER COLUMN "httpAuth" SET DATA TYPE VARCHAR(1024);
+		ALTER TABLE `_entry`
+			ALTER COLUMN "date" SET DATA TYPE BIGINT,
+			ALTER COLUMN "lastSeen" SET DATA TYPE BIGINT,
+			ALTER COLUMN "guid" SET DATA TYPE VARCHAR(767),
+			ALTER COLUMN "title" SET DATA TYPE VARCHAR(8192),
+			ALTER COLUMN "author" SET DATA TYPE VARCHAR(1024),
+			ALTER COLUMN "link" SET DATA TYPE VARCHAR(16383),
+			ALTER COLUMN "tags" SET DATA TYPE VARCHAR(2048);
+		ALTER TABLE `_entrytmp`
+			ALTER COLUMN "date" SET DATA TYPE BIGINT,
+			ALTER COLUMN "lastSeen" SET DATA TYPE BIGINT,
+			ALTER COLUMN "guid" SET DATA TYPE VARCHAR(767),
+			ALTER COLUMN "title" SET DATA TYPE VARCHAR(8192),
+			ALTER COLUMN "author" SET DATA TYPE VARCHAR(1024),
+			ALTER COLUMN "link" SET DATA TYPE VARCHAR(16383),
+			ALTER COLUMN "tags" SET DATA TYPE VARCHAR(2048);
+		ALTER TABLE `_tag`
+			ALTER COLUMN "name" SET DATA TYPE VARCHAR(191);
+	END IF;
+END $$;
+SQL;
