@@ -14,6 +14,17 @@ return array(
 	'about' => array(
 		'_' => 'Par vietni',
 		'agpl3' => '<a href="https://www.gnu.org/licenses/agpl-3.0.html">AGPL 3</a>',	// IGNORE
+		'bug_reports' => array(
+			'environment_information' => array(
+				'_' => 'System information',	// TODO
+				'browser' => 'Browser',	// TODO
+				'database' => 'Database',	// TODO
+				'server_software' => 'Server software',	// TODO
+				'version_curl' => 'cURL version',	// TODO
+				'version_frss' => 'FreshRSS version',	// TODO
+				'version_php' => 'PHP version',	// TODO
+			),
+		),
 		'bugs_reports' => 'Ziņojumi par kļūdām',
 		'credits' => 'Kredīti',
 		'credits_content' => 'Daži dizaina elementi nāk no <a href="http://twitter.github.io/bootstrap/">Bootstrap</a>, lai gan FreshRSS neizmanto šo ietvaru. <a href="https://gitlab.gnome.org/Archive/gnome-icon-theme-symbolic">Ikonas</a> ir no <a href="https://www.gnome.org/">GNOME projekta</a>. <em>Open Sans</em> fontu policiju ir izveidojis <a href="https://fonts.google.com/specimen/Open+Sans">Steve Matteson</a>. FreshRSS pamatā ir PHP ietvarstruktūra <a href="https://framagit.org/marienfressinaud/MINZ">Minz</a>.',
@@ -27,6 +38,11 @@ return array(
 	),
 	'feed' => array(
 		'empty' => 'Nav neviena raksta, ko parādīt.',
+		'received' => array(
+			'before_yesterday' => 'Received before yesterday',	// TODO
+			'today' => 'Received today',	// TODO
+			'yesterday' => 'Received yesterday',	// TODO
+		),
 		'rss_of' => 'RSS plūsma %s',
 		'title' => 'Galvenā plūsma',
 		'title_fav' => 'Mīļākie',
@@ -51,6 +67,7 @@ return array(
 		'mark_cat_read' => 'Atzīmēt kategoriju kā izlasītu',
 		'mark_feed_read' => 'Atzīmēt barotni kā izlasītu',
 		'mark_selection_unread' => 'Atzīmēt izvēlni kā izlasītu',
+		'mylabels' => 'Manas birkas',
 		'newer_first' => 'Sākumā jaunākos',
 		'non-starred' => 'Rādīt neiecienītākos',
 		'normal_view' => 'Parastais skats',
@@ -60,10 +77,21 @@ return array(
 		'reader_view' => 'Lasīšanas skats',
 		'rss_view' => 'RSS barotne',
 		'search_short' => 'Meklēt',
+		'sort' => array(
+			'_' => 'Sorting criteria',	// TODO
+			'date_asc' => 'Publication date 1→9',	// TODO
+			'date_desc' => 'Publication date 9→1',	// TODO
+			'id_asc' => 'Freshly received last',	// TODO
+			'id_desc' => 'Freshly received first',	// TODO
+			'link_asc' => 'Link A→Z',	// TODO
+			'link_desc' => 'Link Z→A',	// TODO
+			'rand' => 'Random order',	// TODO
+			'title_asc' => 'Title A→Z',	// TODO
+			'title_desc' => 'Title Z→A',	// TODO
+		),
 		'starred' => 'Rādīt mīļākos',
 		'stats' => 'Statistika',
 		'subscription' => 'Abonementa pārvalde',
-		'tags' => 'Manas birkas',
 		'unread' => 'Rādīt neizlasītos',
 	),
 	'share' => 'Dalīties',
