@@ -18,14 +18,6 @@ return array(
 		'next_step' => 'Перейти к следующему шагу',
 		'reinstall' => 'Переустановить FreshRSS',
 	),
-	'auth' => array(
-		'form' => 'Веб-форма (традиционный, необходим JavaScript)',
-		'http' => 'HTTP (для опытных пользователей с HTTPS)',
-		'none' => 'Без аутентификации (небезопасно)',
-		'password_form' => 'Пароль<br /><small>(для входа через веб-форму)</small>',
-		'password_format' => 'Не менее 7 символов',
-		'type' => 'Способ аутентификации',
-	),
 	'bdd' => array(
 		'_' => 'База данных',
 		'conf' => array(
