@@ -1,4 +1,6 @@
 <?php
+declare(strict_types=1);
+
 /**
  * MINZ - Copyright 2011 Marien Fressinaud
  * Sous licence AGPL3 <http://www.gnu.org/licenses/>
@@ -7,15 +9,15 @@
 /**
  * The Minz_ActionController class is a controller in the MVC paradigm
  */
-class Minz_ActionController {
+abstract class Minz_ActionController {
 
 	/** @var array<string,string> */
-	private static $csp_default = [
+	private static array $csp_default = [
 		'default-src' => "'self'",
 	];
 
 	/** @var array<string,string> */
-	private $csp_policies;
+	private array $csp_policies;
 
 	/** @var Minz_View */
 	protected $view;
@@ -25,7 +27,7 @@ class Minz_ActionController {
 	 * @var class-string
 	 * @deprecated Use constructor with view type instead
 	 */
-	public static $defaultViewType = Minz_View::class;
+	public static string $defaultViewType = Minz_View::class;
 
 	/**
 	 * @phpstan-param class-string|'' $viewType
@@ -49,7 +51,7 @@ class Minz_ActionController {
 		$this->view = $view ?? new Minz_View();
 		$view_path = Minz_Request::controllerName() . '/' . Minz_Request::actionName() . '.phtml';
 		$this->view->_path($view_path);
-		$this->view->attributeParams ();
+		$this->view->attributeParams();
 	}
 
 	/**
@@ -97,6 +99,9 @@ class Minz_ActionController {
 	 */
 	public function declareCspHeader(): void {
 		$policies = [];
+		foreach (Minz_ExtensionManager::listExtensions(true) as $extension) {
+			$extension->amendCsp($this->csp_policies);
+		}
 		foreach ($this->csp_policies as $directive => $sources) {
 			$policies[] = $directive . ' ' . $sources;
 		}
