@@ -16,5 +16,5 @@ interface Minz_ConfigurationSetterInterface {
 	 * @param string $key the key to update.
 	 * @param mixed $value the value to set.
 	 */
-	public function handle(&$data, string $key, $value): void;
+	public function handle(array &$data, string $key, mixed $value): void;
 }
