@@ -1,4 +1,6 @@
 <?php
+declare(strict_types=1);
+
 // > Error: FreshRSS requires PHP, which does not seem to be installed or configured correctly! <!--
 
 # ***** BEGIN LICENSE BLOCK *****
@@ -30,17 +32,18 @@ if (!file_exists($applied_migrations_path)) {
 	require(APP_PATH . '/install.php');
 } else {
 	session_cache_limiter('');
+	Minz_Session::init('FreshRSS');
+	Minz_Session::_param('keepAlive', 1);	//To prevent the PHP session from expiring
 
 	if (!file_exists(DATA_PATH . '/no-cache.txt')) {
 		require(LIB_PATH . '/http-conditional.php');
 		$currentUser = Minz_User::name();
 		$dateLastModification = $currentUser === null ? time() : max(
-			@filemtime(USERS_PATH . '/' . $currentUser . '/' . LOG_FILENAME) ?: 0,
+			FreshRSS_UserDAO::ctime($currentUser),
+			FreshRSS_UserDAO::mtime($currentUser),
 			@filemtime(DATA_PATH . '/config.php') ?: 0
 		);
-		if (httpConditional($dateLastModification, 0, 0, false, PHP_COMPRESSION, true)) {
-			Minz_Session::init('FreshRSS');
-			Minz_Session::_param('keepAlive', 1);	//To prevent the PHP session from expiring
+		if (httpConditional($dateLastModification ?: time(), 0, 0, false, PHP_COMPRESSION, true)) {
 			exit();	//No need to send anything
 		}
 	}
@@ -53,7 +56,6 @@ if (!file_exists($applied_migrations_path)) {
 			FreshRSS_Context::initSystem();
 			$front_controller = new FreshRSS();
 			$front_controller->init();
-			Minz_Session::_param('keepAlive', 1);	//To prevent the PHP session from expiring
 			$front_controller->run();
 		} else {
 			$error = $result;
