@@ -1,7 +1,7 @@
 <?php
-
+declare(strict_types=1);
 error_reporting(E_ALL);
-ini_set('display_errors', 1);
+ini_set('display_errors', '1');
 
 const COPY_LOG_TO_SYSLOG = false;
 
