@@ -3,7 +3,7 @@ declare(strict_types=1);
 
 class CssXPathTest extends PHPUnit\Framework\TestCase
 {
-	public function testCssXPathTranslatorClassExists(): void {
+	public static function testCssXPathTranslatorClassExists(): void {
 		self::assertTrue(class_exists('Gt\\CssXPath\\Translator'));
 	}
 }
