@@ -5,7 +5,7 @@ use PHPMailer\PHPMailer\PHPMailer;
 
 class PHPMailerTest extends PHPUnit\Framework\TestCase
 {
-	public function testPHPMailerClassExists(): void {
+	public static function testPHPMailerClassExists(): void {
 		self::assertTrue(class_exists(PHPMailer::class));
 	}
 }
